@@ -24,10 +24,11 @@ import Legacy
 import GithubObject
 
 DEFAULT_BASE_URL = "https://api.github.com"
+DEFAULT_TIMEOUT = 10
 
 class Github( object ):
-    def __init__( self, login_or_token = None, password = None, base_url = DEFAULT_BASE_URL ):
-        self.__requester = Requester( login_or_token, password, base_url )
+    def __init__( self, login_or_token = None, password = None, base_url = DEFAULT_BASE_URL, timeout = DEFAULT_TIMEOUT):
+        self.__requester = Requester( login_or_token, password, base_url, timeout )
 
     @property
     def rate_limiting( self ):
